from enum import Enum


class UnitRadioactivityFormat(str, Enum):
    """The valid types of radioactivity unit formats. These describe the amount of radiation emitted by a radioactive material."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Becquerel> """  # noqa: E501
    BECQUEREL = "becquerel"
    """# <https://en.wikipedia.org/wiki/Curie_(unit)> """  # noqa: E501
    CURIE = "curie"
    """# <https://en.wikipedia.org/wiki/Rutherford_(unit)> """  # noqa: E501
    RUTHERFORD = "rutherford"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

S = TypeVar("S", bound="Error")


@attr.s(auto_attribs=True)
class Error:
    """Error information from a response."""  # noqa: E501

    error_code: Union[Unset, str] = UNSET
    message: Union[Unset, str] = UNSET
    request_id: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        error_code = self.error_code
        message = self.message
        request_id = self.request_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if error_code is not UNSET:
            field_dict["error_code"] = error_code
        if message is not UNSET:
            field_dict["message"] = message
        if request_id is not UNSET:
            field_dict["request_id"] = request_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[S], src_dict: Dict[str, Any]) -> S:
        d = src_dict.copy()
        error_code = d.pop("error_code", UNSET)

        message = d.pop("message", UNSET)

        request_id = d.pop("request_id", UNSET)

        error = cls(
            error_code=error_code,
            message=message,
            request_id=request_id,
        )

        error.additional_properties = d
        return error

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CodeLanguage(str, Enum):
    """The language code is written in."""  # noqa: E501

    GO = "go"
    PYTHON = "python"
    NODE = "node"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitIlluminanceFormat(str, Enum):
    """The valid types of illuminance unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Lux> """  # noqa: E501
    LUX = "lux"
    """# <https://en.wikipedia.org/wiki/Foot-candle> """  # noqa: E501
    FOOTCANDLE = "footcandle"
    """# <https://en.wikipedia.org/wiki/Lumen_(unit)> """  # noqa: E501
    LUMENS_PER_SQUARE_INCH = "lumens_per_square_inch"
    """# <https://en.wikipedia.org/wiki/Phot> """  # noqa: E501
    PHOT = "phot"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitSolidAngleFormat(str, Enum):
    """The valid types of solid angle unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Steradian> """  # noqa: E501
    STERADIAN = "steradian"
    """# <https://en.wikipedia.org/wiki/Square_degree> """  # noqa: E501
    DEGREE_SQUARED = "degree_squared"
    """# <https://en.wikipedia.org/wiki/Spat_(angular_unit)> """  # noqa: E501
    SPAT = "spat"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitVolumeFormat(str, Enum):
    """The valid types of volume unit formats."""  # noqa: E501

    """# Unit Meter <https://en.wikipedia.org/wiki/Cubic_metre> """  # noqa: E501
    CUBIC_METER = "cubic_meter"
    """# Centimeter <https://en.wikipedia.org/wiki/Centimetre> """  # noqa: E501
    CUBIC_CENTIMETER = "cubic_centimeter"
    """# Millimeter <https://en.wikipedia.org/wiki/Cubic_metre> """  # noqa: E501
    CUBIC_MILLIMETER = "cubic_millimeter"
    """# Kilometer <https://en.wikipedia.org/wiki/Cubic_metre> """  # noqa: E501
    CUBIC_KILOMETER = "cubic_kilometer"
    """# Unit Liter <https://en.wikipedia.org/wiki/Litre> """  # noqa: E501
    LITER = "liter"
    """# Cubic Inch <https://en.wikipedia.org/wiki/Cubic_inch> """  # noqa: E501
    CUBIC_INCH = "cubic_inch"
    """# Foot <https://en.wikipedia.org/wiki/Cubic_foot> """  # noqa: E501
    CUBIC_FOOT = "cubic_foot"
    """# Yard <https://en.wikipedia.org/wiki/Cubic_foot> """  # noqa: E501
    CUBIC_YARD = "cubic_yard"
    """# Mile <https://en.wikipedia.org/wiki/Cubic_foot> """  # noqa: E501
    CUBIC_MILE = "cubic_mile"
    """# Gallon <https://en.wikipedia.org/wiki/Gallon> """  # noqa: E501
    GALLON = "gallon"
    """# Quart <https://en.wikipedia.org/wiki/Quart> """  # noqa: E501
    QUART = "quart"
    """# Pint <https://en.wikipedia.org/wiki/Pint> """  # noqa: E501
    PINT = "pint"
    """# Cup <https://en.wikipedia.org/wiki/Cup_(unit)> """  # noqa: E501
    CUP = "cup"
    """# Fluid Ounce <https://en.wikipedia.org/wiki/Fluid_ounce> """  # noqa: E501
    FLUID_OUNCE = "fluid_ounce"
    """# Barrel <https://en.wikipedia.org/wiki/Barrel_(unit)> """  # noqa: E501
    BARREL = "barrel"
    """# Bushel <https://en.wikipedia.org/wiki/Bushel> """  # noqa: E501
    BUSHEL = "bushel"
    """# Cord <https://en.wikipedia.org/wiki/Cord_(unit)> """  # noqa: E501
    CORD = "cord"
    """# Cubic Fathom <https://en.wikipedia.org/wiki/Cubic_fathom> """  # noqa: E501
    CUBIC_FATHOM = "cubic_fathom"
    """# Tablespoon <https://en.wikipedia.org/wiki/Tablespoon> """  # noqa: E501
    TABLESPOON = "tablespoon"
    """# Teaspoon <https://en.wikipedia.org/wiki/Teaspoon> """  # noqa: E501
    TEASPOON = "teaspoon"
    """# Pinch <https://en.wikipedia.org/wiki/Pinch_(unit)> """  # noqa: E501
    PINCH = "pinch"
    """# Dash <https://en.wikipedia.org/wiki/Cooking_weights_and_measures> """  # noqa: E501
    DASH = "dash"
    """# Drop <https://en.wikipedia.org/wiki/Cooking_weights_and_measures> """  # noqa: E501
    DROP = "drop"
    """# Fifth <https://en.wikipedia.org/wiki/Fifth_(unit)> """  # noqa: E501
    FIFTH = "fifth"
    """# Dram <https://en.wikipedia.org/wiki/Dram_(unit)> """  # noqa: E501
    DRAM = "dram"
    """# Gill <https://en.wikipedia.org/wiki/Gill_(unit)> """  # noqa: E501
    GILL = "gill"
    """# Peck <https://en.wikipedia.org/wiki/Imperial_units> """  # noqa: E501
    PECK = "peck"
    """# Stack <https://en.wikipedia.org/wiki/Stack_(unit)> """  # noqa: E501
    SACK = "sack"
    """# Shot <https://en.wikipedia.org/wiki/Shot_glass> """  # noqa: E501
    SHOT = "shot"
    """# Strike <https://en.wikipedia.org/wiki/Strike_(unit)> """  # noqa: E501
    STRIKE = "strike"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitChargeFormat(str, Enum):
    """The valid types of charge unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Coulomb> """  # noqa: E501
    COULOMB = "coulomb"
    """# <https://en.wikipedia.org/wiki/Ampere_hour> """  # noqa: E501
    AMPERE_HOUR = "ampere_hour"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitMassFormat(str, Enum):
    """The valid types of mass unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Gram> """  # noqa: E501
    GRAM = "gram"
    """# <https://en.wikipedia.org/wiki/Kilogram> """  # noqa: E501
    KILOGRAM = "kilogram"
    """# <https://en.wikipedia.org/wiki/Tonne> """  # noqa: E501
    METRIC_TON = "metric_ton"
    """# <https://en.wikipedia.org/wiki/Pound_(mass)> """  # noqa: E501
    POUND = "pound"
    """# <https://en.wikipedia.org/wiki/Long_ton> """  # noqa: E501
    LONG_TON = "long_ton"
    """# <https://en.wikipedia.org/wiki/Short_ton> """  # noqa: E501
    SHORT_TON = "short_ton"
    """# <https://en.wikipedia.org/wiki/Stone_(unit)> """  # noqa: E501
    STONE = "stone"
    """# <https://en.wikipedia.org/wiki/Ounce> """  # noqa: E501
    OUNCE = "ounce"
    """# <https://en.wikipedia.org/wiki/Carat_(mass)> """  # noqa: E501
    CARAT = "carat"
    """# <https://en.wikipedia.org/wiki/Slug_(unit)> """  # noqa: E501
    SLUG = "slug"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitEnergyFormat(str, Enum):
    """The valid types of energy unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Joule> """  # noqa: E501
    JOULE = "joule"
    """# <https://en.wikipedia.org/wiki/Calorie> """  # noqa: E501
    CALORIE = "calorie"
    """# <https://en.wikipedia.org/wiki/Kilowatt-hour> """  # noqa: E501
    KILOWATT_HOUR = "kilowatt_hour"
    """# <https://en.wikipedia.org/wiki/Kilowatt-hour> """  # noqa: E501
    WATT_HOUR = "watt_hour"
    """# <https://en.wikipedia.org/wiki/British_thermal_unit> """  # noqa: E501
    BRITISH_THERMAL_UNIT = "british_thermal_unit"
    """# <https://en.wikipedia.org/wiki/Therm#Definitions> """  # noqa: E501
    BRITISH_THERMAL_UNIT_ISO = "british_thermal_unit_iso"
    """# <https://en.wikipedia.org/wiki/Therm#Definitions> """  # noqa: E501
    BRITISH_THERMAL_UNIT59 = "british_thermal_unit59"
    """# <https://en.wikipedia.org/wiki/Therm> """  # noqa: E501
    THERM = "therm"
    """# <https://en.wikipedia.org/wiki/Foot-pound_(energy)> """  # noqa: E501
    FOOT_POUND = "foot_pound"

    def __str__(self) -> str:
        return str(self.value)



import pytest

from kittycad.api.ai import create_image_to_3d, create_text_to_3d
from kittycad.api.api_calls import (
    get_api_call,
    get_api_call_for_user,
    get_api_call_metrics,
    get_async_operation,
    list_api_calls,
    list_api_calls_for_user,
    list_async_operations,
    user_list_api_calls,
)
from kittycad.api.api_tokens import (
    create_api_token_for_user,
    delete_api_token_for_user,
    get_api_token_for_user,
    list_api_tokens_for_user,
)
from kittycad.api.apps import (
    apps_github_callback,
    apps_github_consent,
    apps_github_webhook,
)
from kittycad.api.constant import get_physics_constant
from kittycad.api.drawing import cmd, cmd_batch
from kittycad.api.executor import create_executor_term, create_file_execution
from kittycad.api.file import (
    create_file_center_of_mass,
    create_file_conversion_with_base64_helper,
    create_file_density,
    create_file_mass,
    create_file_surface_area,
    create_file_volume,
)
from kittycad.api.hidden import auth_email, auth_email_callback, logout
from kittycad.api.meta import (
    get_ai_plugin_manifest,
    get_metadata,
    get_metrics,
    get_openai_schema,
    get_schema,
    ping,
)
from kittycad.api.payments import (
    create_payment_information_for_user,
    create_payment_intent_for_user,
    delete_payment_information_for_user,
    delete_payment_method_for_user,
    get_payment_balance_for_user,
    get_payment_information_for_user,
    list_invoices_for_user,
    list_payment_methods_for_user,
    update_payment_information_for_user,
    validate_customer_tax_information_for_user,
)
from kittycad.api.unit import (
    get_acceleration_unit_conversion,
    get_angle_unit_conversion,
    get_angular_velocity_unit_conversion,
    get_area_unit_conversion,
    get_charge_unit_conversion,
    get_concentration_unit_conversion,
    get_data_transfer_rate_unit_conversion,
    get_data_unit_conversion,
    get_density_unit_conversion,
    get_energy_unit_conversion,
    get_force_unit_conversion,
    get_illuminance_unit_conversion,
    get_length_unit_conversion,
    get_magnetic_field_strength_unit_conversion,
    get_magnetic_flux_unit_conversion,
    get_mass_unit_conversion,
    get_metric_power_cubed_unit_conversion,
    get_metric_power_squared_unit_conversion,
    get_metric_power_unit_conversion,
    get_power_unit_conversion,
    get_pressure_unit_conversion,
    get_radiation_unit_conversion,
    get_radioactivity_unit_conversion,
    get_solid_angle_unit_conversion,
    get_temperature_unit_conversion,
    get_time_unit_conversion,
    get_velocity_unit_conversion,
    get_voltage_unit_conversion,
    get_volume_unit_conversion,
)
from kittycad.api.users import (
    delete_user_self,
    get_session_for_user,
    get_user,
    get_user_extended,
    get_user_front_hash_self,
    get_user_onboarding_self,
    get_user_self,
    get_user_self_extended,
    list_users,
    list_users_extended,
    update_user_self,
)
from kittycad.client import ClientFromEnv
from kittycad.models.api_call_query_group_by import ApiCallQueryGroupBy
from kittycad.models.api_call_status import ApiCallStatus
from kittycad.models.billing_info import BillingInfo
from kittycad.models.code_language import CodeLanguage
from kittycad.models.created_at_sort_mode import CreatedAtSortMode
from kittycad.models.drawing_cmd_req import DrawingCmdReq
from kittycad.models.drawing_cmd_req_batch import DrawingCmdReqBatch
from kittycad.models.email_authentication_form import EmailAuthenticationForm
from kittycad.models.file_export_format import FileExportFormat
from kittycad.models.file_import_format import FileImportFormat
from kittycad.models.image_type import ImageType
from kittycad.models.physics_constant_name import PhysicsConstantName
from kittycad.models.unit_acceleration_format import UnitAccelerationFormat
from kittycad.models.unit_angle_format import UnitAngleFormat
from kittycad.models.unit_angular_velocity_format import UnitAngularVelocityFormat
from kittycad.models.unit_area_format import UnitAreaFormat
from kittycad.models.unit_charge_format import UnitChargeFormat
from kittycad.models.unit_concentration_format import UnitConcentrationFormat
from kittycad.models.unit_data_format import UnitDataFormat
from kittycad.models.unit_data_transfer_rate_format import UnitDataTransferRateFormat
from kittycad.models.unit_density_format import UnitDensityFormat
from kittycad.models.unit_energy_format import UnitEnergyFormat
from kittycad.models.unit_force_format import UnitForceFormat
from kittycad.models.unit_illuminance_format import UnitIlluminanceFormat
from kittycad.models.unit_length_format import UnitLengthFormat
from kittycad.models.unit_magnetic_field_strength_format import (
    UnitMagneticFieldStrengthFormat,
)
from kittycad.models.unit_magnetic_flux_format import UnitMagneticFluxFormat
from kittycad.models.unit_mass_format import UnitMassFormat
from kittycad.models.unit_metric_power import UnitMetricPower
from kittycad.models.unit_power_format import UnitPowerFormat
from kittycad.models.unit_pressure_format import UnitPressureFormat
from kittycad.models.unit_radiation_format import UnitRadiationFormat
from kittycad.models.unit_radioactivity_format import UnitRadioactivityFormat
from kittycad.models.unit_solid_angle_format import UnitSolidAngleFormat
from kittycad.models.unit_temperature_format import UnitTemperatureFormat
from kittycad.models.unit_time_format import UnitTimeFormat
from kittycad.models.unit_velocity_format import UnitVelocityFormat
from kittycad.models.unit_voltage_format import UnitVoltageFormat
from kittycad.models.unit_volume_format import UnitVolumeFormat
from kittycad.models.update_user import UpdateUser


@pytest.mark.skip
def test_get_schema():
    # Create our client.
    client = ClientFromEnv()

    get_schema.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_schema.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_schema_async():
    # Create our client.
    client = ClientFromEnv()

    await get_schema.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_schema.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_ai_plugin_manifest():
    # Create our client.
    client = ClientFromEnv()

    get_ai_plugin_manifest.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_ai_plugin_manifest.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_ai_plugin_manifest_async():
    # Create our client.
    client = ClientFromEnv()

    await get_ai_plugin_manifest.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_ai_plugin_manifest.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_metadata():
    # Create our client.
    client = ClientFromEnv()

    get_metadata.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_metadata.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_metadata_async():
    # Create our client.
    client = ClientFromEnv()

    await get_metadata.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_metadata.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_metrics():
    # Create our client.
    client = ClientFromEnv()

    get_metrics.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_metrics.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_metrics_async():
    # Create our client.
    client = ClientFromEnv()

    await get_metrics.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_metrics.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_create_image_to_3d():
    # Create our client.
    client = ClientFromEnv()

    create_image_to_3d.sync(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_image_to_3d.sync_detailed(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_image_to_3d_async():
    # Create our client.
    client = ClientFromEnv()

    await create_image_to_3d.asyncio(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_image_to_3d.asyncio_detailed(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_text_to_3d():
    # Create our client.
    client = ClientFromEnv()

    create_text_to_3d.sync(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )

    # OR if you need more info (e.g. status_code)
    create_text_to_3d.sync_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_text_to_3d_async():
    # Create our client.
    client = ClientFromEnv()

    await create_text_to_3d.asyncio(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )

    # OR run async with more info
    await create_text_to_3d.asyncio_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )


@pytest.mark.skip
def test_get_api_call_metrics():
    # Create our client.
    client = ClientFromEnv()

    get_api_call_metrics.sync(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )

    # OR if you need more info (e.g. status_code)
    get_api_call_metrics.sync_detailed(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_call_metrics_async():
    # Create our client.
    client = ClientFromEnv()

    await get_api_call_metrics.asyncio(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )

    # OR run async with more info
    await get_api_call_metrics.asyncio_detailed(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )


@pytest.mark.skip
def test_list_api_calls():
    # Create our client.
    client = ClientFromEnv()

    list_api_calls.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    list_api_calls.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_api_calls_async():
    # Create our client.
    client = ClientFromEnv()

    await list_api_calls.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await list_api_calls.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_api_call():
    # Create our client.
    client = ClientFromEnv()

    get_api_call.sync(
        client=client,
        id="<string>",
    )

    # OR if you need more info (e.g. status_code)
    get_api_call.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_call_async():
    # Create our client.
    client = ClientFromEnv()

    await get_api_call.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    await get_api_call.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_apps_github_callback():
    # Create our client.
    client = ClientFromEnv()

    apps_github_callback.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    apps_github_callback.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_apps_github_callback_async():
    # Create our client.
    client = ClientFromEnv()

    await apps_github_callback.asyncio(
        client=client,
    )

    # OR run async with more info
    await apps_github_callback.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_apps_github_consent():
    # Create our client.
    client = ClientFromEnv()

    apps_github_consent.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    apps_github_consent.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_apps_github_consent_async():
    # Create our client.
    client = ClientFromEnv()

    await apps_github_consent.asyncio(
        client=client,
    )

    # OR run async with more info
    await apps_github_consent.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_apps_github_webhook():
    # Create our client.
    client = ClientFromEnv()

    apps_github_webhook.sync(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    apps_github_webhook.sync_detailed(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_apps_github_webhook_async():
    # Create our client.
    client = ClientFromEnv()

    await apps_github_webhook.asyncio(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await apps_github_webhook.asyncio_detailed(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_list_async_operations():
    # Create our client.
    client = ClientFromEnv()

    list_async_operations.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    list_async_operations.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_async_operations_async():
    # Create our client.
    client = ClientFromEnv()

    await list_async_operations.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await list_async_operations.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_async_operation():
    # Create our client.
    client = ClientFromEnv()

    get_async_operation.sync(
        client=client,
        id="<string>",
    )

    # OR if you need more info (e.g. status_code)
    get_async_operation.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_async_operation_async():
    # Create our client.
    client = ClientFromEnv()

    await get_async_operation.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    await get_async_operation.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_auth_email():
    # Create our client.
    client = ClientFromEnv()

    auth_email.sync(
        client=client,
        body=EmailAuthenticationForm,
    )

    # OR if you need more info (e.g. status_code)
    auth_email.sync_detailed(
        client=client,
        body=EmailAuthenticationForm,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_auth_email_async():
    # Create our client.
    client = ClientFromEnv()

    await auth_email.asyncio(
        client=client,
        body=EmailAuthenticationForm,
    )

    # OR run async with more info
    await auth_email.asyncio_detailed(
        client=client,
        body=EmailAuthenticationForm,
    )


@pytest.mark.skip
def test_auth_email_callback():
    # Create our client.
    client = ClientFromEnv()

    auth_email_callback.sync(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    auth_email_callback.sync_detailed(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_auth_email_callback_async():
    # Create our client.
    client = ClientFromEnv()

    await auth_email_callback.asyncio(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )

    # OR run async with more info
    await auth_email_callback.asyncio_detailed(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_physics_constant():
    # Create our client.
    client = ClientFromEnv()

    get_physics_constant.sync(
        client=client,
        constant=PhysicsConstantName.PI,
    )

    # OR if you need more info (e.g. status_code)
    get_physics_constant.sync_detailed(
        client=client,
        constant=PhysicsConstantName.PI,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_physics_constant_async():
    # Create our client.
    client = ClientFromEnv()

    await get_physics_constant.asyncio(
        client=client,
        constant=PhysicsConstantName.PI,
    )

    # OR run async with more info
    await get_physics_constant.asyncio_detailed(
        client=client,
        constant=PhysicsConstantName.PI,
    )


@pytest.mark.skip
def test_cmd():
    # Create our client.
    client = ClientFromEnv()

    cmd.sync(
        client=client,
        body=DrawingCmdReq,
    )

    # OR if you need more info (e.g. status_code)
    cmd.sync_detailed(
        client=client,
        body=DrawingCmdReq,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_cmd_async():
    # Create our client.
    client = ClientFromEnv()

    await cmd.asyncio(
        client=client,
        body=DrawingCmdReq,
    )

    # OR run async with more info
    await cmd.asyncio_detailed(
        client=client,
        body=DrawingCmdReq,
    )


@pytest.mark.skip
def test_cmd_batch():
    # Create our client.
    client = ClientFromEnv()

    cmd_batch.sync(
        client=client,
        body=DrawingCmdReqBatch,
    )

    # OR if you need more info (e.g. status_code)
    cmd_batch.sync_detailed(
        client=client,
        body=DrawingCmdReqBatch,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_cmd_batch_async():
    # Create our client.
    client = ClientFromEnv()

    await cmd_batch.asyncio(
        client=client,
        body=DrawingCmdReqBatch,
    )

    # OR run async with more info
    await cmd_batch.asyncio_detailed(
        client=client,
        body=DrawingCmdReqBatch,
    )


@pytest.mark.skip
def test_create_file_center_of_mass():
    # Create our client.
    client = ClientFromEnv()

    create_file_center_of_mass.sync(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_center_of_mass.sync_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_center_of_mass_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_center_of_mass.asyncio(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_file_center_of_mass.asyncio_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_conversion_with_base64_helper():
    # Create our client.
    client = ClientFromEnv()

    create_file_conversion_with_base64_helper.sync(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_conversion_with_base64_helper.sync_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_conversion_with_base64_helper_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_conversion_with_base64_helper.asyncio(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    (
        await create_file_conversion_with_base64_helper.asyncio_detailed(
            client=client,
            output_format=FileExportFormat.DAE,
            src_format=FileImportFormat.DAE,
            body=bytes("some bytes", "utf-8"),
        )
    )


@pytest.mark.skip
def test_create_file_density():
    # Create our client.
    client = ClientFromEnv()

    create_file_density.sync(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_density.sync_detailed(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_density_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_density.asyncio(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_file_density.asyncio_detailed(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_execution():
    # Create our client.
    client = ClientFromEnv()

    create_file_execution.sync(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_execution.sync_detailed(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_execution_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_execution.asyncio(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_file_execution.asyncio_detailed(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_mass():
    # Create our client.
    client = ClientFromEnv()

    create_file_mass.sync(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_mass.sync_detailed(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_mass_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_mass.asyncio(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_file_mass.asyncio_detailed(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_surface_area():
    # Create our client.
    client = ClientFromEnv()

    create_file_surface_area.sync(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_surface_area.sync_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_surface_area_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_surface_area.asyncio(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_file_surface_area.asyncio_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_volume():
    # Create our client.
    client = ClientFromEnv()

    create_file_volume.sync(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR if you need more info (e.g. status_code)
    create_file_volume.sync_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_volume_async():
    # Create our client.
    client = ClientFromEnv()

    await create_file_volume.asyncio(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    await create_file_volume.asyncio_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_logout():
    # Create our client.
    client = ClientFromEnv()

    logout.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    logout.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_logout_async():
    # Create our client.
    client = ClientFromEnv()

    await logout.asyncio(
        client=client,
    )

    # OR run async with more info
    await logout.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_openai_schema():
    # Create our client.
    client = ClientFromEnv()

    get_openai_schema.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_openai_schema.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_openai_schema_async():
    # Create our client.
    client = ClientFromEnv()

    await get_openai_schema.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_openai_schema.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_ping():
    # Create our client.
    client = ClientFromEnv()

    ping.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    ping.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_ping_async():
    # Create our client.
    client = ClientFromEnv()

    await ping.asyncio(
        client=client,
    )

    # OR run async with more info
    await ping.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_acceleration_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_acceleration_unit_conversion.sync(
        client=client,
        output_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
        src_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_acceleration_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
        src_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_acceleration_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_acceleration_unit_conversion.asyncio(
        client=client,
        output_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
        src_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_acceleration_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
            src_format=UnitAccelerationFormat.METERS_PER_SECOND_SQUARED,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_angle_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_angle_unit_conversion.sync(
        client=client,
        output_format=UnitAngleFormat.RADIAN,
        src_format=UnitAngleFormat.RADIAN,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_angle_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitAngleFormat.RADIAN,
        src_format=UnitAngleFormat.RADIAN,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_angle_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_angle_unit_conversion.asyncio(
        client=client,
        output_format=UnitAngleFormat.RADIAN,
        src_format=UnitAngleFormat.RADIAN,
        value=3.14,
    )

    # OR run async with more info
    await get_angle_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitAngleFormat.RADIAN,
        src_format=UnitAngleFormat.RADIAN,
        value=3.14,
    )


@pytest.mark.skip
def test_get_angular_velocity_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_angular_velocity_unit_conversion.sync(
        client=client,
        output_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
        src_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    (
        get_angular_velocity_unit_conversion.sync_detailed(
            client=client,
            output_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
            src_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
            value=3.14,
        )
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_angular_velocity_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    (
        await get_angular_velocity_unit_conversion.asyncio(
            client=client,
            output_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
            src_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
            value=3.14,
        )
    )

    # OR run async with more info
    (
        await get_angular_velocity_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
            src_format=UnitAngularVelocityFormat.RADIANS_PER_SECOND,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_area_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_area_unit_conversion.sync(
        client=client,
        output_format=UnitAreaFormat.SQUARE_METER,
        src_format=UnitAreaFormat.SQUARE_METER,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_area_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitAreaFormat.SQUARE_METER,
        src_format=UnitAreaFormat.SQUARE_METER,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_area_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_area_unit_conversion.asyncio(
        client=client,
        output_format=UnitAreaFormat.SQUARE_METER,
        src_format=UnitAreaFormat.SQUARE_METER,
        value=3.14,
    )

    # OR run async with more info
    await get_area_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitAreaFormat.SQUARE_METER,
        src_format=UnitAreaFormat.SQUARE_METER,
        value=3.14,
    )


@pytest.mark.skip
def test_get_charge_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_charge_unit_conversion.sync(
        client=client,
        output_format=UnitChargeFormat.COULOMB,
        src_format=UnitChargeFormat.COULOMB,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_charge_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitChargeFormat.COULOMB,
        src_format=UnitChargeFormat.COULOMB,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_charge_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_charge_unit_conversion.asyncio(
        client=client,
        output_format=UnitChargeFormat.COULOMB,
        src_format=UnitChargeFormat.COULOMB,
        value=3.14,
    )

    # OR run async with more info
    await get_charge_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitChargeFormat.COULOMB,
        src_format=UnitChargeFormat.COULOMB,
        value=3.14,
    )


@pytest.mark.skip
def test_get_concentration_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_concentration_unit_conversion.sync(
        client=client,
        output_format=UnitConcentrationFormat.PARTS_PER_MILLION,
        src_format=UnitConcentrationFormat.PARTS_PER_MILLION,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_concentration_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitConcentrationFormat.PARTS_PER_MILLION,
        src_format=UnitConcentrationFormat.PARTS_PER_MILLION,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_concentration_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_concentration_unit_conversion.asyncio(
        client=client,
        output_format=UnitConcentrationFormat.PARTS_PER_MILLION,
        src_format=UnitConcentrationFormat.PARTS_PER_MILLION,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_concentration_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitConcentrationFormat.PARTS_PER_MILLION,
            src_format=UnitConcentrationFormat.PARTS_PER_MILLION,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_data_transfer_rate_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_data_transfer_rate_unit_conversion.sync(
        client=client,
        output_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
        src_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    (
        get_data_transfer_rate_unit_conversion.sync_detailed(
            client=client,
            output_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
            src_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
            value=3.14,
        )
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_data_transfer_rate_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    (
        await get_data_transfer_rate_unit_conversion.asyncio(
            client=client,
            output_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
            src_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
            value=3.14,
        )
    )

    # OR run async with more info
    (
        await get_data_transfer_rate_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
            src_format=UnitDataTransferRateFormat.BYTES_PER_SECOND,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_data_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_data_unit_conversion.sync(
        client=client,
        output_format=UnitDataFormat.BYTE,
        src_format=UnitDataFormat.BYTE,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_data_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitDataFormat.BYTE,
        src_format=UnitDataFormat.BYTE,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_data_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_data_unit_conversion.asyncio(
        client=client,
        output_format=UnitDataFormat.BYTE,
        src_format=UnitDataFormat.BYTE,
        value=3.14,
    )

    # OR run async with more info
    await get_data_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitDataFormat.BYTE,
        src_format=UnitDataFormat.BYTE,
        value=3.14,
    )


@pytest.mark.skip
def test_get_density_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_density_unit_conversion.sync(
        client=client,
        output_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        src_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_density_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        src_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_density_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_density_unit_conversion.asyncio(
        client=client,
        output_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        src_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        value=3.14,
    )

    # OR run async with more info
    await get_density_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        src_format=UnitDensityFormat.KILOGRAMS_PER_CUBIC_METER,
        value=3.14,
    )


@pytest.mark.skip
def test_get_energy_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_energy_unit_conversion.sync(
        client=client,
        output_format=UnitEnergyFormat.JOULE,
        src_format=UnitEnergyFormat.JOULE,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_energy_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitEnergyFormat.JOULE,
        src_format=UnitEnergyFormat.JOULE,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_energy_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_energy_unit_conversion.asyncio(
        client=client,
        output_format=UnitEnergyFormat.JOULE,
        src_format=UnitEnergyFormat.JOULE,
        value=3.14,
    )

    # OR run async with more info
    await get_energy_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitEnergyFormat.JOULE,
        src_format=UnitEnergyFormat.JOULE,
        value=3.14,
    )


@pytest.mark.skip
def test_get_force_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_force_unit_conversion.sync(
        client=client,
        output_format=UnitForceFormat.NEWTON,
        src_format=UnitForceFormat.NEWTON,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_force_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitForceFormat.NEWTON,
        src_format=UnitForceFormat.NEWTON,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_force_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_force_unit_conversion.asyncio(
        client=client,
        output_format=UnitForceFormat.NEWTON,
        src_format=UnitForceFormat.NEWTON,
        value=3.14,
    )

    # OR run async with more info
    await get_force_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitForceFormat.NEWTON,
        src_format=UnitForceFormat.NEWTON,
        value=3.14,
    )


@pytest.mark.skip
def test_get_illuminance_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_illuminance_unit_conversion.sync(
        client=client,
        output_format=UnitIlluminanceFormat.LUX,
        src_format=UnitIlluminanceFormat.LUX,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_illuminance_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitIlluminanceFormat.LUX,
        src_format=UnitIlluminanceFormat.LUX,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_illuminance_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_illuminance_unit_conversion.asyncio(
        client=client,
        output_format=UnitIlluminanceFormat.LUX,
        src_format=UnitIlluminanceFormat.LUX,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_illuminance_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitIlluminanceFormat.LUX,
            src_format=UnitIlluminanceFormat.LUX,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_length_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_length_unit_conversion.sync(
        client=client,
        output_format=UnitLengthFormat.METER,
        src_format=UnitLengthFormat.METER,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_length_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitLengthFormat.METER,
        src_format=UnitLengthFormat.METER,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_length_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_length_unit_conversion.asyncio(
        client=client,
        output_format=UnitLengthFormat.METER,
        src_format=UnitLengthFormat.METER,
        value=3.14,
    )

    # OR run async with more info
    await get_length_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitLengthFormat.METER,
        src_format=UnitLengthFormat.METER,
        value=3.14,
    )


@pytest.mark.skip
def test_get_magnetic_field_strength_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    (
        get_magnetic_field_strength_unit_conversion.sync(
            client=client,
            output_format=UnitMagneticFieldStrengthFormat.TESLA,
            src_format=UnitMagneticFieldStrengthFormat.TESLA,
            value=3.14,
        )
    )

    # OR if you need more info (e.g. status_code)
    (
        get_magnetic_field_strength_unit_conversion.sync_detailed(
            client=client,
            output_format=UnitMagneticFieldStrengthFormat.TESLA,
            src_format=UnitMagneticFieldStrengthFormat.TESLA,
            value=3.14,
        )
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_magnetic_field_strength_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    (
        await get_magnetic_field_strength_unit_conversion.asyncio(
            client=client,
            output_format=UnitMagneticFieldStrengthFormat.TESLA,
            src_format=UnitMagneticFieldStrengthFormat.TESLA,
            value=3.14,
        )
    )

    # OR run async with more info
    (
        await get_magnetic_field_strength_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitMagneticFieldStrengthFormat.TESLA,
            src_format=UnitMagneticFieldStrengthFormat.TESLA,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_magnetic_flux_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_magnetic_flux_unit_conversion.sync(
        client=client,
        output_format=UnitMagneticFluxFormat.WEBER,
        src_format=UnitMagneticFluxFormat.WEBER,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_magnetic_flux_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitMagneticFluxFormat.WEBER,
        src_format=UnitMagneticFluxFormat.WEBER,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_magnetic_flux_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_magnetic_flux_unit_conversion.asyncio(
        client=client,
        output_format=UnitMagneticFluxFormat.WEBER,
        src_format=UnitMagneticFluxFormat.WEBER,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_magnetic_flux_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitMagneticFluxFormat.WEBER,
            src_format=UnitMagneticFluxFormat.WEBER,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_mass_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_mass_unit_conversion.sync(
        client=client,
        output_format=UnitMassFormat.GRAM,
        src_format=UnitMassFormat.GRAM,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_mass_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitMassFormat.GRAM,
        src_format=UnitMassFormat.GRAM,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_mass_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_mass_unit_conversion.asyncio(
        client=client,
        output_format=UnitMassFormat.GRAM,
        src_format=UnitMassFormat.GRAM,
        value=3.14,
    )

    # OR run async with more info
    await get_mass_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitMassFormat.GRAM,
        src_format=UnitMassFormat.GRAM,
        value=3.14,
    )


@pytest.mark.skip
def test_get_metric_power_cubed_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_metric_power_cubed_unit_conversion.sync(
        client=client,
        output_format=UnitMetricPower.ATTO,
        src_format=UnitMetricPower.ATTO,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    (
        get_metric_power_cubed_unit_conversion.sync_detailed(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_metric_power_cubed_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    (
        await get_metric_power_cubed_unit_conversion.asyncio(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )

    # OR run async with more info
    (
        await get_metric_power_cubed_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_metric_power_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_metric_power_unit_conversion.sync(
        client=client,
        output_format=UnitMetricPower.ATTO,
        src_format=UnitMetricPower.ATTO,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_metric_power_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitMetricPower.ATTO,
        src_format=UnitMetricPower.ATTO,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_metric_power_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_metric_power_unit_conversion.asyncio(
        client=client,
        output_format=UnitMetricPower.ATTO,
        src_format=UnitMetricPower.ATTO,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_metric_power_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_metric_power_squared_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    (
        get_metric_power_squared_unit_conversion.sync(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )

    # OR if you need more info (e.g. status_code)
    (
        get_metric_power_squared_unit_conversion.sync_detailed(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_metric_power_squared_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    (
        await get_metric_power_squared_unit_conversion.asyncio(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )

    # OR run async with more info
    (
        await get_metric_power_squared_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitMetricPower.ATTO,
            src_format=UnitMetricPower.ATTO,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_power_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_power_unit_conversion.sync(
        client=client,
        output_format=UnitPowerFormat.WATT,
        src_format=UnitPowerFormat.WATT,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_power_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitPowerFormat.WATT,
        src_format=UnitPowerFormat.WATT,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_power_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_power_unit_conversion.asyncio(
        client=client,
        output_format=UnitPowerFormat.WATT,
        src_format=UnitPowerFormat.WATT,
        value=3.14,
    )

    # OR run async with more info
    await get_power_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitPowerFormat.WATT,
        src_format=UnitPowerFormat.WATT,
        value=3.14,
    )


@pytest.mark.skip
def test_get_pressure_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_pressure_unit_conversion.sync(
        client=client,
        output_format=UnitPressureFormat.PASCAL,
        src_format=UnitPressureFormat.PASCAL,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_pressure_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitPressureFormat.PASCAL,
        src_format=UnitPressureFormat.PASCAL,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_pressure_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_pressure_unit_conversion.asyncio(
        client=client,
        output_format=UnitPressureFormat.PASCAL,
        src_format=UnitPressureFormat.PASCAL,
        value=3.14,
    )

    # OR run async with more info
    await get_pressure_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitPressureFormat.PASCAL,
        src_format=UnitPressureFormat.PASCAL,
        value=3.14,
    )


@pytest.mark.skip
def test_get_radiation_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_radiation_unit_conversion.sync(
        client=client,
        output_format=UnitRadiationFormat.GRAY,
        src_format=UnitRadiationFormat.GRAY,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_radiation_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitRadiationFormat.GRAY,
        src_format=UnitRadiationFormat.GRAY,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_radiation_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_radiation_unit_conversion.asyncio(
        client=client,
        output_format=UnitRadiationFormat.GRAY,
        src_format=UnitRadiationFormat.GRAY,
        value=3.14,
    )

    # OR run async with more info
    await get_radiation_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitRadiationFormat.GRAY,
        src_format=UnitRadiationFormat.GRAY,
        value=3.14,
    )


@pytest.mark.skip
def test_get_radioactivity_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_radioactivity_unit_conversion.sync(
        client=client,
        output_format=UnitRadioactivityFormat.BECQUEREL,
        src_format=UnitRadioactivityFormat.BECQUEREL,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_radioactivity_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitRadioactivityFormat.BECQUEREL,
        src_format=UnitRadioactivityFormat.BECQUEREL,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_radioactivity_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_radioactivity_unit_conversion.asyncio(
        client=client,
        output_format=UnitRadioactivityFormat.BECQUEREL,
        src_format=UnitRadioactivityFormat.BECQUEREL,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_radioactivity_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitRadioactivityFormat.BECQUEREL,
            src_format=UnitRadioactivityFormat.BECQUEREL,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_solid_angle_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_solid_angle_unit_conversion.sync(
        client=client,
        output_format=UnitSolidAngleFormat.STERADIAN,
        src_format=UnitSolidAngleFormat.STERADIAN,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_solid_angle_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitSolidAngleFormat.STERADIAN,
        src_format=UnitSolidAngleFormat.STERADIAN,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_solid_angle_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_solid_angle_unit_conversion.asyncio(
        client=client,
        output_format=UnitSolidAngleFormat.STERADIAN,
        src_format=UnitSolidAngleFormat.STERADIAN,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_solid_angle_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitSolidAngleFormat.STERADIAN,
            src_format=UnitSolidAngleFormat.STERADIAN,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_temperature_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_temperature_unit_conversion.sync(
        client=client,
        output_format=UnitTemperatureFormat.KELVIN,
        src_format=UnitTemperatureFormat.KELVIN,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_temperature_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitTemperatureFormat.KELVIN,
        src_format=UnitTemperatureFormat.KELVIN,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_temperature_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_temperature_unit_conversion.asyncio(
        client=client,
        output_format=UnitTemperatureFormat.KELVIN,
        src_format=UnitTemperatureFormat.KELVIN,
        value=3.14,
    )

    # OR run async with more info
    (
        await get_temperature_unit_conversion.asyncio_detailed(
            client=client,
            output_format=UnitTemperatureFormat.KELVIN,
            src_format=UnitTemperatureFormat.KELVIN,
            value=3.14,
        )
    )


@pytest.mark.skip
def test_get_time_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_time_unit_conversion.sync(
        client=client,
        output_format=UnitTimeFormat.SECOND,
        src_format=UnitTimeFormat.SECOND,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_time_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitTimeFormat.SECOND,
        src_format=UnitTimeFormat.SECOND,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_time_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_time_unit_conversion.asyncio(
        client=client,
        output_format=UnitTimeFormat.SECOND,
        src_format=UnitTimeFormat.SECOND,
        value=3.14,
    )

    # OR run async with more info
    await get_time_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitTimeFormat.SECOND,
        src_format=UnitTimeFormat.SECOND,
        value=3.14,
    )


@pytest.mark.skip
def test_get_velocity_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_velocity_unit_conversion.sync(
        client=client,
        output_format=UnitVelocityFormat.METERS_PER_SECOND,
        src_format=UnitVelocityFormat.METERS_PER_SECOND,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_velocity_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitVelocityFormat.METERS_PER_SECOND,
        src_format=UnitVelocityFormat.METERS_PER_SECOND,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_velocity_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_velocity_unit_conversion.asyncio(
        client=client,
        output_format=UnitVelocityFormat.METERS_PER_SECOND,
        src_format=UnitVelocityFormat.METERS_PER_SECOND,
        value=3.14,
    )

    # OR run async with more info
    await get_velocity_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitVelocityFormat.METERS_PER_SECOND,
        src_format=UnitVelocityFormat.METERS_PER_SECOND,
        value=3.14,
    )


@pytest.mark.skip
def test_get_voltage_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_voltage_unit_conversion.sync(
        client=client,
        output_format=UnitVoltageFormat.VOLT,
        src_format=UnitVoltageFormat.VOLT,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_voltage_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitVoltageFormat.VOLT,
        src_format=UnitVoltageFormat.VOLT,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_voltage_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_voltage_unit_conversion.asyncio(
        client=client,
        output_format=UnitVoltageFormat.VOLT,
        src_format=UnitVoltageFormat.VOLT,
        value=3.14,
    )

    # OR run async with more info
    await get_voltage_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitVoltageFormat.VOLT,
        src_format=UnitVoltageFormat.VOLT,
        value=3.14,
    )


@pytest.mark.skip
def test_get_volume_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    get_volume_unit_conversion.sync(
        client=client,
        output_format=UnitVolumeFormat.CUBIC_METER,
        src_format=UnitVolumeFormat.CUBIC_METER,
        value=3.14,
    )

    # OR if you need more info (e.g. status_code)
    get_volume_unit_conversion.sync_detailed(
        client=client,
        output_format=UnitVolumeFormat.CUBIC_METER,
        src_format=UnitVolumeFormat.CUBIC_METER,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_volume_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    await get_volume_unit_conversion.asyncio(
        client=client,
        output_format=UnitVolumeFormat.CUBIC_METER,
        src_format=UnitVolumeFormat.CUBIC_METER,
        value=3.14,
    )

    # OR run async with more info
    await get_volume_unit_conversion.asyncio_detailed(
        client=client,
        output_format=UnitVolumeFormat.CUBIC_METER,
        src_format=UnitVolumeFormat.CUBIC_METER,
        value=3.14,
    )


@pytest.mark.skip
def test_delete_user_self():
    # Create our client.
    client = ClientFromEnv()

    delete_user_self.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    delete_user_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_user_self_async():
    # Create our client.
    client = ClientFromEnv()

    await delete_user_self.asyncio(
        client=client,
    )

    # OR run async with more info
    await delete_user_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_user_self():
    # Create our client.
    client = ClientFromEnv()

    get_user_self.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_user_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_self_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user_self.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_user_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_update_user_self():
    # Create our client.
    client = ClientFromEnv()

    update_user_self.sync(
        client=client,
        body=UpdateUser,
    )

    # OR if you need more info (e.g. status_code)
    update_user_self.sync_detailed(
        client=client,
        body=UpdateUser,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_update_user_self_async():
    # Create our client.
    client = ClientFromEnv()

    await update_user_self.asyncio(
        client=client,
        body=UpdateUser,
    )

    # OR run async with more info
    await update_user_self.asyncio_detailed(
        client=client,
        body=UpdateUser,
    )


@pytest.mark.skip
def test_user_list_api_calls():
    # Create our client.
    client = ClientFromEnv()

    user_list_api_calls.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    user_list_api_calls.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_user_list_api_calls_async():
    # Create our client.
    client = ClientFromEnv()

    await user_list_api_calls.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await user_list_api_calls.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_api_call_for_user():
    # Create our client.
    client = ClientFromEnv()

    get_api_call_for_user.sync(
        client=client,
        id="<string>",
    )

    # OR if you need more info (e.g. status_code)
    get_api_call_for_user.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_call_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await get_api_call_for_user.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    await get_api_call_for_user.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_list_api_tokens_for_user():
    # Create our client.
    client = ClientFromEnv()

    list_api_tokens_for_user.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    list_api_tokens_for_user.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_api_tokens_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await list_api_tokens_for_user.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await list_api_tokens_for_user.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_create_api_token_for_user():
    # Create our client.
    client = ClientFromEnv()

    create_api_token_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    create_api_token_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_api_token_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await create_api_token_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await create_api_token_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_delete_api_token_for_user():
    # Create our client.
    client = ClientFromEnv()

    delete_api_token_for_user.sync(
        client=client,
        token="<uuid>",
    )

    # OR if you need more info (e.g. status_code)
    delete_api_token_for_user.sync_detailed(
        client=client,
        token="<uuid>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_api_token_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await delete_api_token_for_user.asyncio(
        client=client,
        token="<uuid>",
    )

    # OR run async with more info
    await delete_api_token_for_user.asyncio_detailed(
        client=client,
        token="<uuid>",
    )


@pytest.mark.skip
def test_get_api_token_for_user():
    # Create our client.
    client = ClientFromEnv()

    get_api_token_for_user.sync(
        client=client,
        token="<uuid>",
    )

    # OR if you need more info (e.g. status_code)
    get_api_token_for_user.sync_detailed(
        client=client,
        token="<uuid>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_token_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await get_api_token_for_user.asyncio(
        client=client,
        token="<uuid>",
    )

    # OR run async with more info
    await get_api_token_for_user.asyncio_detailed(
        client=client,
        token="<uuid>",
    )


@pytest.mark.skip
def test_get_user_self_extended():
    # Create our client.
    client = ClientFromEnv()

    get_user_self_extended.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_user_self_extended.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_self_extended_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user_self_extended.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_user_self_extended.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_user_front_hash_self():
    # Create our client.
    client = ClientFromEnv()

    get_user_front_hash_self.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_user_front_hash_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_front_hash_self_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user_front_hash_self.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_user_front_hash_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_user_onboarding_self():
    # Create our client.
    client = ClientFromEnv()

    get_user_onboarding_self.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_user_onboarding_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_onboarding_self_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user_onboarding_self.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_user_onboarding_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_delete_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    delete_payment_information_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    delete_payment_information_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await delete_payment_information_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await delete_payment_information_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    get_payment_information_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_payment_information_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await get_payment_information_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_payment_information_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_create_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    create_payment_information_for_user.sync(
        client=client,
        body=BillingInfo,
    )

    # OR if you need more info (e.g. status_code)
    create_payment_information_for_user.sync_detailed(
        client=client,
        body=BillingInfo,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await create_payment_information_for_user.asyncio(
        client=client,
        body=BillingInfo,
    )

    # OR run async with more info
    await create_payment_information_for_user.asyncio_detailed(
        client=client,
        body=BillingInfo,
    )


@pytest.mark.skip
def test_update_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    update_payment_information_for_user.sync(
        client=client,
        body=BillingInfo,
    )

    # OR if you need more info (e.g. status_code)
    update_payment_information_for_user.sync_detailed(
        client=client,
        body=BillingInfo,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_update_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await update_payment_information_for_user.asyncio(
        client=client,
        body=BillingInfo,
    )

    # OR run async with more info
    await update_payment_information_for_user.asyncio_detailed(
        client=client,
        body=BillingInfo,
    )


@pytest.mark.skip
def test_get_payment_balance_for_user():
    # Create our client.
    client = ClientFromEnv()

    get_payment_balance_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_payment_balance_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_payment_balance_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await get_payment_balance_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_payment_balance_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_create_payment_intent_for_user():
    # Create our client.
    client = ClientFromEnv()

    create_payment_intent_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    create_payment_intent_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_payment_intent_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await create_payment_intent_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await create_payment_intent_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_list_invoices_for_user():
    # Create our client.
    client = ClientFromEnv()

    list_invoices_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    list_invoices_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_invoices_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await list_invoices_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await list_invoices_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_list_payment_methods_for_user():
    # Create our client.
    client = ClientFromEnv()

    list_payment_methods_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    list_payment_methods_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_payment_methods_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await list_payment_methods_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await list_payment_methods_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_delete_payment_method_for_user():
    # Create our client.
    client = ClientFromEnv()

    delete_payment_method_for_user.sync(
        client=client,
        id="<string>",
    )

    # OR if you need more info (e.g. status_code)
    delete_payment_method_for_user.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_payment_method_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await delete_payment_method_for_user.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    await delete_payment_method_for_user.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_validate_customer_tax_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    validate_customer_tax_information_for_user.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    validate_customer_tax_information_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_validate_customer_tax_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await validate_customer_tax_information_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    await validate_customer_tax_information_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_session_for_user():
    # Create our client.
    client = ClientFromEnv()

    get_session_for_user.sync(
        client=client,
        token="<uuid>",
    )

    # OR if you need more info (e.g. status_code)
    get_session_for_user.sync_detailed(
        client=client,
        token="<uuid>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_session_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await get_session_for_user.asyncio(
        client=client,
        token="<uuid>",
    )

    # OR run async with more info
    await get_session_for_user.asyncio_detailed(
        client=client,
        token="<uuid>",
    )


@pytest.mark.skip
def test_list_users():
    # Create our client.
    client = ClientFromEnv()

    list_users.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    list_users.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_users_async():
    # Create our client.
    client = ClientFromEnv()

    await list_users.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await list_users.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_list_users_extended():
    # Create our client.
    client = ClientFromEnv()

    list_users_extended.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    list_users_extended.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_users_extended_async():
    # Create our client.
    client = ClientFromEnv()

    await list_users_extended.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await list_users_extended.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_user_extended():
    # Create our client.
    client = ClientFromEnv()

    get_user_extended.sync(
        client=client,
        id="<string>",
    )

    # OR if you need more info (e.g. status_code)
    get_user_extended.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_extended_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user_extended.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    await get_user_extended.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_get_user():
    # Create our client.
    client = ClientFromEnv()

    get_user.sync(
        client=client,
        id="<string>",
    )

    # OR if you need more info (e.g. status_code)
    get_user.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    await get_user.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_list_api_calls_for_user():
    # Create our client.
    client = ClientFromEnv()

    list_api_calls_for_user.sync(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR if you need more info (e.g. status_code)
    list_api_calls_for_user.sync_detailed(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_api_calls_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    await list_api_calls_for_user.asyncio(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    await list_api_calls_for_user.asyncio_detailed(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_create_executor_term():
    # Create our client.
    client = ClientFromEnv()

    create_executor_term.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    create_executor_term.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_executor_term_async():
    # Create our client.
    client = ClientFromEnv()

    await create_executor_term.asyncio(
        client=client,
    )

    # OR run async with more info
    await create_executor_term.asyncio_detailed(
        client=client,
    )



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

R = TypeVar("R", bound="VerificationToken")


@attr.s(auto_attribs=True)
class VerificationToken:
    """A verification token for a user.

    This is typically used to verify a user's email address."""  # noqa: E501

    created_at: Union[Unset, datetime.datetime] = UNSET
    expires: Union[Unset, datetime.datetime] = UNSET
    id: Union[Unset, str] = UNSET
    identifier: Union[Unset, str] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()
        expires: Union[Unset, str] = UNSET
        if not isinstance(self.expires, Unset):
            expires = self.expires.isoformat()
        id = self.id
        identifier = self.identifier
        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if expires is not UNSET:
            field_dict["expires"] = expires
        if id is not UNSET:
            field_dict["id"] = id
        if identifier is not UNSET:
            field_dict["identifier"] = identifier
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[R], src_dict: Dict[str, Any]) -> R:
        d = src_dict.copy()
        _created_at = d.pop("created_at", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _expires = d.pop("expires", UNSET)
        expires: Union[Unset, datetime.datetime]
        if isinstance(_expires, Unset):
            expires = UNSET
        else:
            expires = isoparse(_expires)

        id = d.pop("id", UNSET)

        identifier = d.pop("identifier", UNSET)

        _updated_at = d.pop("updated_at", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        verification_token = cls(
            created_at=created_at,
            expires=expires,
            id=id,
            identifier=identifier,
            updated_at=updated_at,
        )

        verification_token.additional_properties = d
        return verification_token

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UnitConcentrationFormat(str, Enum):
    """The valid types of concentration unit formats."""  # noqa: E501

    """# Per Million - <https://en.wikipedia.org/wiki/Parts-per_notation> """  # noqa: E501
    PARTS_PER_MILLION = "parts_per_million"
    """# Per Billion - <https://en.wikipedia.org/wiki/Parts-per_notation> """  # noqa: E501
    PARTS_PER_BILLION = "parts_per_billion"
    """# Per Trillion - <https://en.wikipedia.org/wiki/Parts-per_notation> """  # noqa: E501
    PARTS_PER_TRILLION = "parts_per_trillion"
    """# <https://en.wikipedia.org/wiki/Concentration>, <https://en.wikipedia.org/wiki/Percentage> """  # noqa: E501
    PERCENT = "percent"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

F = TypeVar("F", bound="DeviceAuthVerifyParams")


@attr.s(auto_attribs=True)
class DeviceAuthVerifyParams:
    """The request parameters to verify the `user_code` for the OAuth 2.0 Device Authorization Grant."""  # noqa: E501

    user_code: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_code = self.user_code

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user_code is not UNSET:
            field_dict["user_code"] = user_code

        return field_dict

    @classmethod
    def from_dict(cls: Type[F], src_dict: Dict[str, Any]) -> F:
        d = src_dict.copy()
        user_code = d.pop("user_code", UNSET)

        device_auth_verify_params = cls(
            user_code=user_code,
        )

        device_auth_verify_params.additional_properties = d
        return device_auth_verify_params

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UnitMetricPower(str, Enum):
    """The valid types of metric unit formats."""  # noqa: E501

    """# Atto (symbol a) is a unit prefix in the metric system denoting a factor of 10^−18 or 0.000000000000000001. <https://en.wikipedia.org/wiki/Atto-> """  # noqa: E501
    ATTO = "atto"
    """# Femto (symbol f) is a unit prefix in the metric system denoting a factor of 10^-15. <https://en.wikipedia.org/wiki/Femto-> """  # noqa: E501
    FEMTO = "femto"
    """# Pico (unit symbol p) is a unit prefix in the metric system denoting a factor of one trillionth in the short scale and one billionth in the long scale (0.000000000001); that is, 10^−12. <https://en.wikipedia.org/wiki/Pico-> """  # noqa: E501
    PICO = "pico"
    """# Nano (symbol n) is a unit prefix meaning "one billionth". Used primarily with the metric system, this prefix denotes a factor of 10^−9 or 0.000000001. <https://en.wikipedia.org/wiki/Nano-> """  # noqa: E501
    NANO = "nano"
    """# Micro (Greek letter μ (U+03BC) or the legacy symbol µ (U+00B5)) is a unit prefix in the metric system denoting a factor of 10^−6 (one millionth). <https://en.wikipedia.org/wiki/Micro-> """  # noqa: E501
    MICRO = "micro"
    """# Milli (symbol m) is a unit prefix in the metric system denoting a factor of one thousandth (10^−3). <https://en.wikipedia.org/wiki/Milli-> """  # noqa: E501
    MILLI = "milli"
    """# Centi (symbol c) is a unit prefix in the metric system denoting a factor of one hundredth. <https://en.wikipedia.org/wiki/Centi-> """  # noqa: E501
    CENTI = "centi"
    """# Deci (symbol d) is a decimal unit prefix in the metric system denoting a factor of one tenth. <https://en.wikipedia.org/wiki/Deci-> """  # noqa: E501
    DECI = "deci"
    """# One metric unit. """  # noqa: E501
    UNIT = "unit"
    """# Deca is a decimal unit prefix in the metric system denoting a factor of ten. <https://en.wikipedia.org/wiki/Deca-> """  # noqa: E501
    DECA = "deca"
    """# Hecto (symbol: h) is a decimal unit prefix in the metric system denoting a factor of one hundred. <https://en.wikipedia.org/wiki/Hecto-> """  # noqa: E501
    HECTO = "hecto"
    """# Kilo is a decimal unit prefix in the metric system denoting multiplication by one thousand (10^3). <https://en.wikipedia.org/wiki/Kilo-> """  # noqa: E501
    KILO = "kilo"
    """# Mega is a unit prefix in metric systems of units denoting a factor of one million (10^6 or 1000000). <https://en.wikipedia.org/wiki/Mega-> """  # noqa: E501
    MEGA = "mega"
    """# Giga is a unit prefix in the metric system denoting a factor of a short-scale billion or long-scale milliard (10^9 or 1000000000). <https://en.wikipedia.org/wiki/Giga-> """  # noqa: E501
    GIGA = "giga"
    """# Tera is a unit prefix in the metric system denoting multiplication by one trillion, or 10^12 or 1000000000000 (one trillion short scale; one billion long scale). <https://en.wikipedia.org/wiki/Tera-> """  # noqa: E501
    TERA = "tera"
    """# Peta is a decimal unit prefix in the metric system denoting multiplication by one quadrillion, or 10^15 (1000000000000000). <https://en.wikipedia.org/wiki/Peta-> """  # noqa: E501
    PETA = "peta"
    """# Exa is a decimal unit prefix in the metric system denoting 10^18 or 1000000000000000000. <https://en.wikipedia.org/wiki/Exa-> """  # noqa: E501
    EXA = "exa"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitMagneticFluxFormat(str, Enum):
    """The valid types of magnetic flux unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Weber_(unit)> """  # noqa: E501
    WEBER = "weber"
    """# <https://en.wikipedia.org/wiki/Maxwell_(unit)> """  # noqa: E501
    MAXWELL = "maxwell"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitDensityFormat(str, Enum):
    """The valid types of density unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Kilogram_per_cubic_metre> """  # noqa: E501
    KILOGRAMS_PER_CUBIC_METER = "kilograms_per_cubic_meter"
    """# <https://en.wikipedia.org/wiki/Specific_density> """  # noqa: E501
    GRAMS_PER_MILLILITER = "grams_per_milliliter"
    """# <https://en.wikipedia.org/wiki/Kilogram_per_cubic_metre> """  # noqa: E501
    KILOGRAMS_PER_LITER = "kilograms_per_liter"
    """# <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    OUNCES_PER_CUBIC_FOOT = "ounces_per_cubic_foot"
    """# <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    OUNCES_PER_CUBIC_INCH = "ounces_per_cubic_inch"
    """# <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    OUNCES_PER_GALLON = "ounces_per_gallon"
    """# <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    POUNDS_PER_CUBIC_FOOT = "pounds_per_cubic_foot"
    """# <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    POUNDS_PER_CUBIC_INCH = "pounds_per_cubic_inch"
    """# <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    POUNDS_PER_GALLON = "pounds_per_gallon"
    """# <https://en.wikipedia.org/wiki/Slug_(unit)> and <https://en.wikipedia.org/wiki/Density#Unit> """  # noqa: E501
    SLUGS_PER_CUBIC_FOOT = "slugs_per_cubic_foot"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitLengthFormat(str, Enum):
    """The valid types of length unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Metre> """  # noqa: E501
    METER = "meter"
    """# <https://en.wikipedia.org/wiki/Millimetre> """  # noqa: E501
    MILLIMETER = "millimeter"
    """# <https://en.wikipedia.org/wiki/Centimetre> """  # noqa: E501
    CENTIMETER = "centimeter"
    """# <https://en.wikipedia.org/wiki/Kilometre> """  # noqa: E501
    KILOMETER = "kilometer"
    """# <https://en.wikipedia.org/wiki/Foot_(unit)> """  # noqa: E501
    FOOT = "foot"
    """# <https://en.wikipedia.org/wiki/Thousandth_of_an_inch> """  # noqa: E501
    MIL = "mil"
    """# <https://en.wikipedia.org/wiki/Inch> """  # noqa: E501
    INCH = "inch"
    """# <https://en.wikipedia.org/wiki/Mile> """  # noqa: E501
    MILE = "mile"
    """# <https://en.wikipedia.org/wiki/Nautical_mile> """  # noqa: E501
    NAUTICAL_MILE = "nautical_mile"
    """# <https://en.wikipedia.org/wiki/Astronomical_unit> """  # noqa: E501
    ASTRONOMICAL_UNIT = "astronomical_unit"
    """# <https://en.wikipedia.org/wiki/Light-year> """  # noqa: E501
    LIGHTYEAR = "lightyear"
    """# <https://en.wikipedia.org/wiki/Parsec> """  # noqa: E501
    PARSEC = "parsec"
    """# <https://en.wikipedia.org/wiki/Angstrom> """  # noqa: E501
    ANGSTROM = "angstrom"
    """# <https://en.wikipedia.org/wiki/Cubit> """  # noqa: E501
    CUBIT = "cubit"
    """# <https://en.wikipedia.org/wiki/Fathom> """  # noqa: E501
    FATHOM = "fathom"
    """# <https://en.wikipedia.org/wiki/Chain_(unit)> """  # noqa: E501
    CHAIN = "chain"
    """# <https://en.wikipedia.org/wiki/Furlong> """  # noqa: E501
    FURLONG = "furlong"
    """# <https://en.wikipedia.org/wiki/Hand_(unit)> """  # noqa: E501
    HAND = "hand"
    """# <https://en.wikipedia.org/wiki/League_(unit)> """  # noqa: E501
    LEAGUE = "league"
    """# <https://en.wikipedia.org/wiki/List_of_nautical_units_of_measurement> """  # noqa: E501
    NAUTICAL_LEAGUE = "nautical_league"
    """# <https://en.wikipedia.org/wiki/Yard> """  # noqa: E501
    YARD = "yard"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class FileExportFormat(str, Enum):
    """The valid types of output file formats."""  # noqa: E501

    """# The COLLADA/DAE file format. <https://en.wikipedia.org/wiki/COLLADA> """  # noqa: E501
    DAE = "dae"
    """# The DXF file format. <https://en.wikipedia.org/wiki/AutoCAD_DXF> """  # noqa: E501
    DXF = "dxf"
    """# The FBX file format. <https://en.wikipedia.org/wiki/FBX> """  # noqa: E501
    FBX = "fbx"
    """# The FBX file format (in binary). <https://en.wikipedia.org/wiki/FBX> """  # noqa: E501
    FBXB = "fbxb"
    """# The OBJ file format. A zip file containing both the obj file itself and its associated mtl file for full processing. <https://en.wikipedia.org/wiki/Wavefront_.obj_file>> The OBJ file format. <https://en.wikipedia.org/wiki/Wavefront_.obj_file> It may or may not have an an attached material (mtl // mtllib) within the file, but we interact with it as if it does not. """  # noqa: E501
    OBJ = "obj"
    """# The PLY file format. <https://en.wikipedia.org/wiki/PLY_(file_format)> """  # noqa: E501
    PLY = "ply"
    """# The STEP file format. <https://en.wikipedia.org/wiki/ISO_10303-21> """  # noqa: E501
    STEP = "step"
    """# The STL file format. <https://en.wikipedia.org/wiki/STL_(file_format)> """  # noqa: E501
    STL = "stl"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

H = TypeVar("H", bound="MetaClusterInfo")


@attr.s(auto_attribs=True)
class MetaClusterInfo:
    """Jetstream statistics."""  # noqa: E501

    cluster_size: Union[Unset, int] = UNSET
    leader: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cluster_size = self.cluster_size
        leader = self.leader
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cluster_size is not UNSET:
            field_dict["cluster_size"] = cluster_size
        if leader is not UNSET:
            field_dict["leader"] = leader
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[H], src_dict: Dict[str, Any]) -> H:
        d = src_dict.copy()
        cluster_size = d.pop("cluster_size", UNSET)

        leader = d.pop("leader", UNSET)

        name = d.pop("name", UNSET)

        meta_cluster_info = cls(
            cluster_size=cluster_size,
            leader=leader,
            name=name,
        )

        meta_cluster_info.additional_properties = d
        return meta_cluster_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class Environment(str, Enum):
    """The environment the server is running in."""  # noqa: E501

    DEVELOPMENT = "DEVELOPMENT"
    PREVIEW = "PREVIEW"
    PRODUCTION = "PRODUCTION"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.cache_metadata import CacheMetadata
from ..models.connection import Connection
from ..models.engine_metadata import EngineMetadata
from ..models.environment import Environment
from ..models.executor_metadata import ExecutorMetadata
from ..models.file_system_metadata import FileSystemMetadata
from ..models.point_e_metadata import PointEMetadata
from ..types import UNSET, Unset

N = TypeVar("N", bound="Metadata")


@attr.s(auto_attribs=True)
class Metadata:
    """Metadata about our currently running server.

    This is mostly used for internal purposes and debugging."""  # noqa: E501

    cache: Union[Unset, CacheMetadata] = UNSET
    engine: Union[Unset, EngineMetadata] = UNSET
    environment: Union[Unset, Environment] = UNSET
    executor: Union[Unset, ExecutorMetadata] = UNSET
    fs: Union[Unset, FileSystemMetadata] = UNSET
    git_hash: Union[Unset, str] = UNSET
    point_e: Union[Unset, PointEMetadata] = UNSET
    pubsub: Union[Unset, Connection] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.cache, Unset):
            cache = self.cache
        if not isinstance(self.engine, Unset):
            engine = self.engine
        if not isinstance(self.environment, Unset):
            environment = self.environment
        if not isinstance(self.executor, Unset):
            executor = self.executor
        if not isinstance(self.fs, Unset):
            fs = self.fs
        git_hash = self.git_hash
        if not isinstance(self.point_e, Unset):
            point_e = self.point_e
        if not isinstance(self.pubsub, Unset):
            pubsub = self.pubsub

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cache is not UNSET:
            field_dict["cache"] = cache
        if engine is not UNSET:
            field_dict["engine"] = engine
        if environment is not UNSET:
            field_dict["environment"] = environment
        if executor is not UNSET:
            field_dict["executor"] = executor
        if fs is not UNSET:
            field_dict["fs"] = fs
        if git_hash is not UNSET:
            field_dict["git_hash"] = git_hash
        if point_e is not UNSET:
            field_dict["point_e"] = point_e
        if pubsub is not UNSET:
            field_dict["pubsub"] = pubsub

        return field_dict

    @classmethod
    def from_dict(cls: Type[N], src_dict: Dict[str, Any]) -> N:
        d = src_dict.copy()
        _cache = d.pop("cache", UNSET)
        cache: Union[Unset, CacheMetadata]
        if isinstance(_cache, Unset):
            cache = UNSET
        else:
            cache = CacheMetadata(_cache)

        _engine = d.pop("engine", UNSET)
        engine: Union[Unset, EngineMetadata]
        if isinstance(_engine, Unset):
            engine = UNSET
        else:
            engine = EngineMetadata(_engine)

        _environment = d.pop("environment", UNSET)
        environment: Union[Unset, Environment]
        if isinstance(_environment, Unset):
            environment = UNSET
        else:
            environment = Environment(_environment)

        _executor = d.pop("executor", UNSET)
        executor: Union[Unset, ExecutorMetadata]
        if isinstance(_executor, Unset):
            executor = UNSET
        else:
            executor = ExecutorMetadata(_executor)

        _fs = d.pop("fs", UNSET)
        fs: Union[Unset, FileSystemMetadata]
        if isinstance(_fs, Unset):
            fs = UNSET
        else:
            fs = FileSystemMetadata(_fs)

        git_hash = d.pop("git_hash", UNSET)

        _point_e = d.pop("point_e", UNSET)
        point_e: Union[Unset, PointEMetadata]
        if isinstance(_point_e, Unset):
            point_e = UNSET
        else:
            point_e = PointEMetadata(_point_e)

        _pubsub = d.pop("pubsub", UNSET)
        pubsub: Union[Unset, Connection]
        if isinstance(_pubsub, Unset):
            pubsub = UNSET
        else:
            pubsub = Connection(_pubsub)

        metadata = cls(
            cache=cache,
            engine=engine,
            environment=environment,
            executor=executor,
            fs=fs,
            git_hash=git_hash,
            point_e=point_e,
            pubsub=pubsub,
        )

        metadata.additional_properties = d
        return metadata

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.drawing_cmd_id import DrawingCmdId
from ..types import UNSET, Unset

J = TypeVar("J", bound="DrawCircle")


@attr.s(auto_attribs=True)
class DrawCircle:
    center: Union[Unset, List[float]] = UNSET
    radius: Union[Unset, float] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        center: Union[Unset, List[float]] = UNSET
        if not isinstance(self.center, Unset):
            center = self.center
        radius = self.radius

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if center is not UNSET:
            field_dict["center"] = center
        if radius is not UNSET:
            field_dict["radius"] = radius

        return field_dict

    @classmethod
    def from_dict(cls: Type[J], src_dict: Dict[str, Any]) -> J:
        d = src_dict.copy()
        center = cast(List[float], d.pop("center", UNSET))

        radius = d.pop("radius", UNSET)

        draw_circle = cls(
            center=center,
            radius=radius,
        )

        draw_circle.additional_properties = d
        return draw_circle

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


V = TypeVar("V", bound="Extrude")


@attr.s(auto_attribs=True)
class Extrude:
    distance: Union[Unset, float] = UNSET
    sketch: Union[Unset, DrawingCmdId] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        distance = self.distance
        if not isinstance(self.sketch, Unset):
            sketch = self.sketch

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if distance is not UNSET:
            field_dict["distance"] = distance
        if sketch is not UNSET:
            field_dict["sketch"] = sketch

        return field_dict

    @classmethod
    def from_dict(cls: Type[V], src_dict: Dict[str, Any]) -> V:
        d = src_dict.copy()
        distance = d.pop("distance", UNSET)

        _sketch = d.pop("sketch", UNSET)
        sketch: Union[Unset, DrawingCmdId]
        if isinstance(_sketch, Unset):
            sketch = UNSET
        else:
            sketch = DrawingCmdId(_sketch)

        extrude = cls(
            distance=distance,
            sketch=sketch,
        )

        extrude.additional_properties = d
        return extrude

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


DrawingCmd = Union[DrawCircle, Extrude]



""" Contains all the data models used in inputs/outputs """

from .account_provider import AccountProvider
from .ai_plugin_api import AiPluginApi
from .ai_plugin_api_type import AiPluginApiType
from .ai_plugin_auth import AiPluginAuth
from .ai_plugin_auth_type import AiPluginAuthType
from .ai_plugin_http_auth_type import AiPluginHttpAuthType
from .ai_plugin_manifest import AiPluginManifest
from .api_call_query_group import ApiCallQueryGroup
from .api_call_query_group_by import ApiCallQueryGroupBy
from .api_call_status import ApiCallStatus
from .api_call_with_price import ApiCallWithPrice
from .api_call_with_price_results_page import ApiCallWithPriceResultsPage
from .api_token import ApiToken
from .api_token_results_page import ApiTokenResultsPage
from .app_client_info import AppClientInfo
from .async_api_call import AsyncApiCall
from .async_api_call_output import AsyncApiCallOutput
from .async_api_call_results_page import AsyncApiCallResultsPage
from .async_api_call_type import AsyncApiCallType
from .billing_info import BillingInfo
from .cache_metadata import CacheMetadata
from .card_details import CardDetails
from .cluster import Cluster
from .code_language import CodeLanguage
from .code_output import CodeOutput
from .commit import Commit
from .connection import Connection
from .country_code import CountryCode
from .created_at_sort_mode import CreatedAtSortMode
from .currency import Currency
from .customer import Customer
from .customer_balance import CustomerBalance
from .device_access_token_request_form import DeviceAccessTokenRequestForm
from .device_auth_request_form import DeviceAuthRequestForm
from .device_auth_verify_params import DeviceAuthVerifyParams
from .docker_system_info import DockerSystemInfo
from .drawing_cmd import DrawingCmd
from .drawing_cmd_id import DrawingCmdId
from .drawing_cmd_req import DrawingCmdReq
from .drawing_cmd_req_batch import DrawingCmdReqBatch
from .drawing_error import DrawingError
from .drawing_outcome import DrawingOutcome
from .drawing_outcomes import DrawingOutcomes
from .email_authentication_form import EmailAuthenticationForm
from .engine_metadata import EngineMetadata
from .environment import Environment
from .error import Error
from .executor_metadata import ExecutorMetadata
from .extended_user import ExtendedUser
from .extended_user_results_page import ExtendedUserResultsPage
from .file_center_of_mass import FileCenterOfMass
from .file_conversion import FileConversion
from .file_density import FileDensity
from .file_export_format import FileExportFormat
from .file_import_format import FileImportFormat
from .file_mass import FileMass
from .file_surface_area import FileSurfaceArea
from .file_system_metadata import FileSystemMetadata
from .file_volume import FileVolume
from .gateway import Gateway
from .image_type import ImageType
from .index_info import IndexInfo
from .invoice import Invoice
from .invoice_line_item import InvoiceLineItem
from .invoice_status import InvoiceStatus
from .jetstream import Jetstream
from .jetstream_api_stats import JetstreamApiStats
from .jetstream_config import JetstreamConfig
from .jetstream_stats import JetstreamStats
from .leaf_node import LeafNode
from .mesh import Mesh
from .meta_cluster_info import MetaClusterInfo
from .metadata import Metadata
from .method import Method
from .new_address import NewAddress
from .o_auth2_client_info import OAuth2ClientInfo
from .o_auth2_grant_type import OAuth2GrantType
from .onboarding import Onboarding
from .output_file import OutputFile
from .payment_intent import PaymentIntent
from .payment_method import PaymentMethod
from .payment_method_card_checks import PaymentMethodCardChecks
from .payment_method_type import PaymentMethodType
from .physics_constant import PhysicsConstant
from .physics_constant_name import PhysicsConstantName
from .plugins_info import PluginsInfo
from .point_e_metadata import PointEMetadata
from .pong import Pong
from .registry_service_config import RegistryServiceConfig
from .runtime import Runtime
from .session import Session
from .system_info_cgroup_driver_enum import SystemInfoCgroupDriverEnum
from .system_info_cgroup_version_enum import SystemInfoCgroupVersionEnum
from .system_info_default_address_pools import SystemInfoDefaultAddressPools
from .system_info_isolation_enum import SystemInfoIsolationEnum
from .unit_acceleration_conversion import UnitAccelerationConversion
from .unit_acceleration_format import UnitAccelerationFormat
from .unit_angle_conversion import UnitAngleConversion
from .unit_angle_format import UnitAngleFormat
from .unit_angular_velocity_conversion import UnitAngularVelocityConversion
from .unit_angular_velocity_format import UnitAngularVelocityFormat
from .unit_area_conversion import UnitAreaConversion
from .unit_area_format import UnitAreaFormat
from .unit_charge_conversion import UnitChargeConversion
from .unit_charge_format import UnitChargeFormat
from .unit_concentration_conversion import UnitConcentrationConversion
from .unit_concentration_format import UnitConcentrationFormat
from .unit_data_conversion import UnitDataConversion
from .unit_data_format import UnitDataFormat
from .unit_data_transfer_rate_conversion import UnitDataTransferRateConversion
from .unit_data_transfer_rate_format import UnitDataTransferRateFormat
from .unit_density_conversion import UnitDensityConversion
from .unit_density_format import UnitDensityFormat
from .unit_energy_conversion import UnitEnergyConversion
from .unit_energy_format import UnitEnergyFormat
from .unit_force_conversion import UnitForceConversion
from .unit_force_format import UnitForceFormat
from .unit_illuminance_conversion import UnitIlluminanceConversion
from .unit_illuminance_format import UnitIlluminanceFormat
from .unit_length_conversion import UnitLengthConversion
from .unit_length_format import UnitLengthFormat
from .unit_magnetic_field_strength_conversion import UnitMagneticFieldStrengthConversion
from .unit_magnetic_field_strength_format import UnitMagneticFieldStrengthFormat
from .unit_magnetic_flux_conversion import UnitMagneticFluxConversion
from .unit_magnetic_flux_format import UnitMagneticFluxFormat
from .unit_mass_conversion import UnitMassConversion
from .unit_mass_format import UnitMassFormat
from .unit_metric_power import UnitMetricPower
from .unit_metric_power_conversion import UnitMetricPowerConversion
from .unit_metric_power_cubed_conversion import UnitMetricPowerCubedConversion
from .unit_metric_power_squared_conversion import UnitMetricPowerSquaredConversion
from .unit_power_conversion import UnitPowerConversion
from .unit_power_format import UnitPowerFormat
from .unit_pressure_conversion import UnitPressureConversion
from .unit_pressure_format import UnitPressureFormat
from .unit_radiation_conversion import UnitRadiationConversion
from .unit_radiation_format import UnitRadiationFormat
from .unit_radioactivity_conversion import UnitRadioactivityConversion
from .unit_radioactivity_format import UnitRadioactivityFormat
from .unit_solid_angle_conversion import UnitSolidAngleConversion
from .unit_solid_angle_format import UnitSolidAngleFormat
from .unit_temperature_conversion import UnitTemperatureConversion
from .unit_temperature_format import UnitTemperatureFormat
from .unit_time_conversion import UnitTimeConversion
from .unit_time_format import UnitTimeFormat
from .unit_velocity_conversion import UnitVelocityConversion
from .unit_velocity_format import UnitVelocityFormat
from .unit_voltage_conversion import UnitVoltageConversion
from .unit_voltage_format import UnitVoltageFormat
from .unit_volume_conversion import UnitVolumeConversion
from .unit_volume_format import UnitVolumeFormat
from .update_user import UpdateUser
from .user import User
from .user_results_page import UserResultsPage
from .uuid import Uuid
from .verification_token import VerificationToken



from enum import Enum


class UnitPowerFormat(str, Enum):
    """The valid types of power unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Watt> """  # noqa: E501
    WATT = "watt"
    """# <https://en.wikipedia.org/wiki/Horsepower> """  # noqa: E501
    HORSEPOWER = "horsepower"
    """# <https://en.wikipedia.org/wiki/Watt#Milliwatt> """  # noqa: E501
    MILLIWATT = "milliwatt"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitVoltageFormat(str, Enum):
    """The valid types of voltage unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Volt> """  # noqa: E501
    VOLT = "volt"
    """# <https://en.wikipedia.org/wiki/Statvolt> """  # noqa: E501
    STATVOLT = "statvolt"
    """# <https://en.wikipedia.org/wiki/Abvolt> """  # noqa: E501
    ABVOLT = "abvolt"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitPressureFormat(str, Enum):
    """The valid types of pressure unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Pascal_(unit)> """  # noqa: E501
    PASCAL = "pascal"
    """# <https://en.wikipedia.org/wiki/Bar_(unit)> """  # noqa: E501
    BAR = "bar"
    """# MilliBar <https://en.wikipedia.org/wiki/Bar_(unit)> """  # noqa: E501
    MBAR = "mbar"
    """# <https://en.wikipedia.org/wiki/Standard_atmosphere_(unit)> """  # noqa: E501
    ATMOSPHERE = "atmosphere"
    """# psi - <https://en.wikipedia.org/wiki/Pound_per_square_inch> """  # noqa: E501
    POUNDS_PER_SQUARE_INCH = "pounds_per_square_inch"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

J = TypeVar("J", bound="PaymentIntent")


@attr.s(auto_attribs=True)
class PaymentIntent:
    """A payment intent response."""  # noqa: E501

    client_secret: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        client_secret = self.client_secret

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if client_secret is not UNSET:
            field_dict["client_secret"] = client_secret

        return field_dict

    @classmethod
    def from_dict(cls: Type[J], src_dict: Dict[str, Any]) -> J:
        d = src_dict.copy()
        client_secret = d.pop("client_secret", UNSET)

        payment_intent = cls(
            client_secret=client_secret,
        )

        payment_intent.additional_properties = d
        return payment_intent

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UnitRadiationFormat(str, Enum):
    """The valid types of radiation unit formats. These describe the radiation energy absorbed by a mass or material and/or how it affects the relative damage to the human body."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Gray_(unit)> """  # noqa: E501
    GRAY = "gray"
    """# <https://en.wikipedia.org/wiki/Sievert> """  # noqa: E501
    SIEVERT = "sievert"
    """# <https://en.wikipedia.org/wiki/Rad_(unit)> """  # noqa: E501
    RAD = "rad"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAccelerationFormat(str, Enum):
    """The valid types of acceleration unit formats."""  # noqa: E501

    """# Acceleration in m/s^2 unit form """  # noqa: E501
    METERS_PER_SECOND_SQUARED = "meters_per_second_squared"
    """# Acceleration in ft/s^2 unit form """  # noqa: E501
    FEET_PER_SECOND_SQUARED = "feet_per_second_squared"
    """# Acceleration in standard gravity (g) unit form (aka where 9.80665 m/s^2 is the base unit). <https://en.wikipedia.org/wiki/Standard_gravity> """  # noqa: E501
    STANDARD_GRAVITY = "standard_gravity"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitDataFormat(str, Enum):
    """The valid types of data unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Byte> """  # noqa: E501
    BYTE = "byte"
    """# <https://en.wikipedia.org/wiki/Byte#Multiple-byte_units> """  # noqa: E501
    EXABYTE = "exabyte"
    """# <https://en.wikipedia.org/wiki/Bit> """  # noqa: E501
    BIT = "bit"
    """# <https://en.wikipedia.org/wiki/Exabit> """  # noqa: E501
    EXABIT = "exabit"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAreaFormat(str, Enum):
    """The valid types of area unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Square_metre> """  # noqa: E501
    SQUARE_METER = "square_meter"
    """# <https://en.wikipedia.org/wiki/Square_foot> """  # noqa: E501
    SQUARE_FOOT = "square_foot"
    """# <https://en.wikipedia.org/wiki/Square_inch> """  # noqa: E501
    SQUARE_INCH = "square_inch"
    """# <https://en.wikipedia.org/wiki/Square_mile> """  # noqa: E501
    SQUARE_MILE = "square_mile"
    """# <https://en.wikipedia.org/wiki/Square_kilometre> """  # noqa: E501
    SQUARE_KILOMETER = "square_kilometer"
    """# <https://en.wikipedia.org/wiki/Hectare> """  # noqa: E501
    HECTARE = "hectare"
    """# <https://en.wikipedia.org/wiki/Acre> """  # noqa: E501
    ACRE = "acre"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAngularVelocityFormat(str, Enum):
    """The valid types of angular velocity unit formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Radian_per_second> """  # noqa: E501
    RADIANS_PER_SECOND = "radians_per_second"
    """# <https://en.wikipedia.org/wiki/Rotational_speed> """  # noqa: E501
    DEGREES_PER_SECOND = "degrees_per_second"
    """# <https://en.wikipedia.org/wiki/Revolutions_per_minute> """  # noqa: E501
    REVOLUTIONS_PER_MINUTE = "revolutions_per_minute"
    """# <https://en.wikipedia.org/wiki/Minute_and_second_of_arc#Symbols_and_abbreviations> """  # noqa: E501
    MILLIARCSECONDS_PER_YEAR = "milliarcseconds_per_year"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.error import Error
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/user".format(client.base_url)  # noqa: E501

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, Error]]:
    if response.status_code == 204:
        response_204 = None
        return response_204
    if response.status_code == 400:
        response_4XX = Error.from_dict(response.json())
        return response_4XX
    if response.status_code == 500:
        response_5XX = Error.from_dict(response.json())
        return response_5XX
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Any, Error]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[Union[Any, Error]]:
    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.delete(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[Union[Any, Error]]:
    """This endpoint requires authentication by any KittyCAD user. It deletes the authenticated user from KittyCAD's database.
    This call will only succeed if all invoices associated with the user have been paid in full and there is no outstanding balance."""  # noqa: E501

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[Union[Any, Error]]:
    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[Union[Any, Error]]:
    """This endpoint requires authentication by any KittyCAD user. It deletes the authenticated user from KittyCAD's database.
    This call will only succeed if all invoices associated with the user have been paid in full and there is no outstanding balance."""  # noqa: E501

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from enum import Enum


class UnitAngleFormat(str, Enum):
    """The valid types of angle formats."""  # noqa: E501

    """# <https://en.wikipedia.org/wiki/Radian> """  # noqa: E501
    RADIAN = "radian"
    """# <https://en.wikipedia.org/wiki/Degree_(angle)> """  # noqa: E501
    DEGREE = "degree"
    """# <https://en.wikipedia.org/wiki/Minute_and_second_of_arc> """  # noqa: E501
    ARCMINUTE = "arcminute"
    """# <https://en.wikipedia.org/wiki/Minute_and_second_of_arc> """  # noqa: E501
    ARCSECOND = "arcsecond"
    """# <https://en.wikipedia.org/wiki/Minute_and_second_of_arc#Symbols_and_abbreviations> """  # noqa: E501
    MILLIARCSECOND = "milliarcsecond"
    """# <https://en.wikipedia.org/wiki/Turn_(angle)> """  # noqa: E501
    TURN = "turn"
    """# <https://en.wikipedia.org/wiki/Gradian> """  # noqa: E501
    GRADIAN = "gradian"

    def __str__(self) -> str:
        return str(self.value)
